@@ -158,19 +158,31 @@ namespace SourceGit
             }
         }
 
-        public static async Task<bool> AskConfirmAsync(string message, Action onSure)
+        public static async Task<bool> AskConfirmAsync(string message)
         {
             if (Current?.ApplicationLifetime is IClassicDesktopStyleApplicationLifetime { MainWindow: { } owner })
             {
                 var confirm = new Views.Confirm();
                 confirm.Message.Text = message;
-                confirm.OnSure = onSure;
                 return await confirm.ShowDialog<bool>(owner);
             }
 
             return false;
         }
 
+        public static async Task<Models.ConfirmEmptyCommitResult> AskConfirmEmptyCommitAsync(bool hasLocalChanges)
+        {
+            if (Current?.ApplicationLifetime is IClassicDesktopStyleApplicationLifetime { MainWindow: { } owner })
+            {
+                var confirm = new Views.ConfirmEmptyCommit();
+                confirm.TxtMessage.Text = Text(hasLocalChanges ? "ConfirmEmptyCommit.WithLocalChanges" : "ConfirmEmptyCommit.NoLocalChanges");
+                confirm.BtnStageAllAndCommit.IsVisible = hasLocalChanges;
+                return await confirm.ShowDialog<Models.ConfirmEmptyCommitResult>(owner);
+            }
+
+            return Models.ConfirmEmptyCommitResult.Cancel;
+        }
+
         public static void RaiseException(string context, string message)
         {
             if (Current is App { _launcher: not null } app)
@@ -578,7 +590,7 @@ namespace SourceGit
         {
             if (!string.IsNullOrEmpty(repo) && Directory.Exists(repo))
             {
-                var test = new Commands.QueryRepositoryRootPath(repo).GetResultAsync().Result;
+                var test = new Commands.QueryRepositoryRootPath(repo).GetResult();
                 if (test.IsSuccess && !string.IsNullOrEmpty(test.StdOut))
                 {
                     Dispatcher.UIThread.Invoke(() =>
@@ -609,10 +621,10 @@ namespace SourceGit
                 try
                 {
                     // Fetch latest release information.
-                    using var client = new HttpClient() { Timeout = TimeSpan.FromSeconds(5) };
-                    var data = await client.GetStringAsync("https://sourcegit-scm.github.io/data/version.json");
+                    using var client = new HttpClient();
+                    client.Timeout = TimeSpan.FromSeconds(5);
 
-                    // Parse JSON into Models.Version.
+                    var data = await client.GetStringAsync("https://sourcegit-scm.github.io/data/version.json");
                     var ver = JsonSerializer.Deserialize(data, JsonCodeGen.Default.Version);
                     if (ver == null)
                         return;
