@@ -1,6 +1,7 @@
 ﻿using System;
 using System.Collections.Generic;
 using System.Text;
+using System.Threading.Tasks;
 
 namespace SourceGit.Commands
 {
@@ -20,11 +21,11 @@ namespace SourceGit.Commands
 
             if (method == Models.CommitSearchMethod.ByAuthor)
             {
-                search += $"-i --author=\"{filter}\"";
+                search += $"-i --author={filter.Quoted()}";
             }
             else if (method == Models.CommitSearchMethod.ByCommitter)
             {
-                search += $"-i --committer=\"{filter}\"";
+                search += $"-i --committer={filter.Quoted()}";
             }
             else if (method == Models.CommitSearchMethod.ByMessage)
             {
@@ -33,21 +34,18 @@ namespace SourceGit.Commands
 
                 var words = filter.Split([' ', '\t', '\r'], StringSplitOptions.RemoveEmptyEntries);
                 foreach (var word in words)
-                {
-                    var escaped = word.Trim().Replace("\"", "\\\"", StringComparison.Ordinal);
-                    argsBuilder.Append($"--grep=\"{escaped}\" ");
-                }
+                    argsBuilder.Append("--grep=").Append(word.Trim().Quoted()).Append(' ');
                 argsBuilder.Append("--all-match -i");
 
                 search = argsBuilder.ToString();
             }
             else if (method == Models.CommitSearchMethod.ByPath)
             {
-                search += $"-- \"{filter}\"";
+                search += $"-- {filter.Quoted()}";
             }
             else
             {
-                search = $"-G\"{filter}\"";
+                search = $"-G{filter.Quoted()}";
             }
 
             WorkingDirectory = repo;
@@ -56,9 +54,9 @@ namespace SourceGit.Commands
             _findFirstMerged = false;
         }
 
-        public List<Models.Commit> Result()
+        public async Task<List<Models.Commit>> GetResultAsync()
         {
-            var rs = ReadToEnd();
+            var rs = await ReadToEndAsync().ConfigureAwait(false);
             if (!rs.IsSuccess)
                 return _commits;
 
@@ -79,8 +77,8 @@ namespace SourceGit.Commands
                         break;
                     case 2:
                         _current.ParseDecorators(line);
-                        if (_current.IsMerged && !_isHeadFounded)
-                            _isHeadFounded = true;
+                        if (_current.IsMerged && !_isHeadFound)
+                            _isHeadFound = true;
                         break;
                     case 3:
                         _current.Author = Models.User.FindOrAdd(line);
@@ -109,8 +107,8 @@ namespace SourceGit.Commands
             if (start < rs.StdOut.Length)
                 _current.Subject = rs.StdOut.Substring(start);
 
-            if (_findFirstMerged && !_isHeadFounded && _commits.Count > 0)
-                MarkFirstMerged();
+            if (_findFirstMerged && !_isHeadFound && _commits.Count > 0)
+                await MarkFirstMergedAsync().ConfigureAwait(false);
 
             return _commits;
         }
@@ -120,21 +118,19 @@ namespace SourceGit.Commands
             if (data.Length < 8)
                 return;
 
-            _current.Parents.AddRange(data.Split(separator: ' ', options: StringSplitOptions.RemoveEmptyEntries));
+            _current.Parents.AddRange(data.Split(' ', StringSplitOptions.RemoveEmptyEntries));
         }
 
-        private void MarkFirstMerged()
+        private async Task MarkFirstMergedAsync()
         {
-            Args = $"log --since=\"{_commits[^1].CommitterTimeStr}\" --format=\"%H\"";
+            Args = $"log --since={_commits[^1].CommitterTimeStr.Quoted()} --format=\"%H\"";
 
-            var rs = ReadToEnd();
+            var rs = await ReadToEndAsync().ConfigureAwait(false);
             var shas = rs.StdOut.Split(['\r', '\n'], StringSplitOptions.RemoveEmptyEntries);
             if (shas.Length == 0)
                 return;
 
-            var set = new HashSet<string>();
-            foreach (var sha in shas)
-                set.Add(sha);
+            var set = new HashSet<string>(shas);
 
             foreach (var c in _commits)
             {
@@ -149,6 +145,6 @@ namespace SourceGit.Commands
         private List<Models.Commit> _commits = new List<Models.Commit>();
         private Models.Commit _current = null;
         private bool _findFirstMerged = false;
-        private bool _isHeadFounded = false;
+        private bool _isHeadFound = false;
     }
 }
