@@ -1,4 +1,4 @@
-﻿using System;
+using System;
 using System.IO;
 
 using Avalonia.Data.Converters;
@@ -22,7 +22,7 @@ namespace SourceGit.Converters
                 var home = Environment.GetFolderPath(Environment.SpecialFolder.UserProfile);
                 var prefixLen = home.EndsWith('/') ? home.Length - 1 : home.Length;
                 if (v.StartsWith(home, StringComparison.Ordinal))
-                    return "~" + v.Substring(prefixLen);
+                    return $"~{v.AsSpan(prefixLen)}";
 
                 return v;
             });
