@@ -1,63 +1,36 @@
 using System.Collections.Generic;
-using Avalonia.Collections;
 using CommunityToolkit.Mvvm.ComponentModel;
 
 namespace SourceGit.ViewModels
 {
     public class BlockNavigation : ObservableObject
     {
-        public class Block
+        public record Block(int Start, int End)
         {
-            public int Start { get; set; } = 0;
-            public int End { get; set; } = 0;
-
-            public Block(int start, int end)
-            {
-                Start = start;
-                End = end;
-            }
-
             public bool IsInRange(int line)
             {
                 return line >= Start && line <= End;
             }
         }
 
-        public AvaloniaList<Block> Blocks
-        {
-            get;
-        } = [];
-
-        public int Current
-        {
-            get => _current;
-            private set => SetProperty(ref _current, value);
-        }
-
         public string Indicator
         {
             get
             {
-                if (Blocks.Count == 0)
+                if (_blocks.Count == 0)
                     return "-/-";
 
-                if (_current >= 0 && _current < Blocks.Count)
-                    return $"{_current + 1}/{Blocks.Count}";
+                if (_current >= 0 && _current < _blocks.Count)
+                    return $"{_current + 1}/{_blocks.Count}";
 
-                return $"-/{Blocks.Count}";
+                return $"-/{_blocks.Count}";
             }
         }
 
-        public BlockNavigation(object context)
+        public BlockNavigation(List<Models.TextDiffLine> lines)
         {
-            Blocks.Clear();
-            Current = -1;
-
-            var lines = new List<Models.TextDiffLine>();
-            if (context is Models.TextDiff combined)
-                lines = combined.Lines;
-            else if (context is TwoSideTextDiff twoSide)
-                lines = twoSide.Old;
+            _blocks.Clear();
+            _current = -1;
 
             if (lines.Count == 0)
                 return;
@@ -91,54 +64,89 @@ namespace SourceGit.ViewModels
             if (!isNewBlock)
                 blocks.Add(new Block(blockStartIdx, lines.Count - 1));
 
-            Blocks.AddRange(blocks);
+            _blocks.AddRange(blocks);
         }
 
         public Block GetCurrentBlock()
         {
-            return (_current >= 0 && _current < Blocks.Count) ? Blocks[_current] : null;
+            if (_current >= 0 && _current < _blocks.Count)
+                return _blocks[_current];
+
+            return null;
         }
 
         public Block GotoFirst()
         {
-            if (Blocks.Count == 0)
+            if (_blocks.Count == 0)
                 return null;
 
-            Current = 0;
-            return Blocks[_current];
+            _current = 0;
+            OnPropertyChanged(nameof(Indicator));
+            return _blocks[_current];
         }
 
         public Block GotoPrev()
         {
-            if (Blocks.Count == 0)
+            if (_blocks.Count == 0)
                 return null;
 
             if (_current == -1)
-                Current = 0;
+                _current = 0;
             else if (_current > 0)
-                Current = _current - 1;
-            return Blocks[_current];
+                _current--;
+
+            OnPropertyChanged(nameof(Indicator));
+            return _blocks[_current];
         }
 
         public Block GotoNext()
         {
-            if (Blocks.Count == 0)
+            if (_blocks.Count == 0)
                 return null;
 
-            if (_current < Blocks.Count - 1)
-                Current = _current + 1;
-            return Blocks[_current];
+            if (_current < _blocks.Count - 1)
+                _current++;
+
+            OnPropertyChanged(nameof(Indicator));
+            return _blocks[_current];
         }
 
         public Block GotoLast()
         {
-            if (Blocks.Count == 0)
+            if (_blocks.Count == 0)
                 return null;
 
-            Current = Blocks.Count - 1;
-            return Blocks[_current];
+            _current = _blocks.Count - 1;
+            OnPropertyChanged(nameof(Indicator));
+            return _blocks[_current];
         }
 
-        private int _current = -1;
+        public void UpdateByCaretPosition(int caretLine)
+        {
+            if (_current >= 0 && _current < _blocks.Count)
+            {
+                var block = _blocks[_current];
+                if (block.IsInRange(caretLine))
+                    return;
+            }
+
+            _current = -1;
+
+            for (var i = 0; i < _blocks.Count; i++)
+            {
+                var block = _blocks[i];
+                if (block.Start > caretLine)
+                    break;
+
+                _current = i;
+                if (block.End >= caretLine)
+                    break;
+            }
+
+            OnPropertyChanged(nameof(Indicator));
+        }
+
+        private int _current;
+        private readonly List<Block> _blocks = [];
     }
 }
