@@ -47,7 +47,7 @@ namespace SourceGit.ViewModels
                 if (refs.Count == 0)
                 {
                     var msg = App.Text("Checkout.WarnLostCommits");
-                    var shouldContinue = await App.AskConfirmAsync(msg, null);
+                    var shouldContinue = await App.AskConfirmAsync(msg);
                     if (!shouldContinue)
                     {
                         _repo.SetWatcherEnabled(true);
@@ -103,7 +103,7 @@ namespace SourceGit.ViewModels
 
             var b = _repo.Branches.Find(x => x.IsLocal && x.Name == Branch);
             if (b != null && _repo.HistoriesFilterMode == Models.FilterMode.Included)
-                _repo.SetBranchFilterMode(b, Models.FilterMode.Included, true, false);
+                _repo.SetBranchFilterMode(b, Models.FilterMode.Included, false, false);
 
             _repo.MarkBranchesDirtyManually();
             _repo.SetWatcherEnabled(true);
