@@ -1,7 +1,6 @@
 ﻿using System.ComponentModel.DataAnnotations;
 using System.IO;
 using System.Threading.Tasks;
-using Avalonia.Threading;
 
 namespace SourceGit.ViewModels
 {
@@ -54,16 +53,7 @@ namespace SourceGit.ViewModels
             _useSSH = Models.Remote.IsSSH(remote.URL);
 
             if (_useSSH)
-            {
-                Task.Run(async () =>
-                {
-                    var sshKey = await new Commands.Config(repo.FullPath)
-                        .GetAsync($"remote.{remote.Name}.sshkey")
-                        .ConfigureAwait(false);
-
-                    Dispatcher.UIThread.Post(() => SSHKey = sshKey);
-                });
-            }
+                _sshkey = new Commands.Config(repo.FullPath).Get($"remote.{remote.Name}.sshkey");
         }
 
         public static ValidationResult ValidateRemoteName(string name, ValidationContext ctx)
