@@ -10,10 +10,19 @@ namespace SourceGit.ViewModels
             get => _repo.Remotes;
         }
 
+        public bool IsFetchAllRemoteVisible
+        {
+            get;
+        }
+
         public bool FetchAllRemotes
         {
             get => _fetchAllRemotes;
-            set => SetProperty(ref _fetchAllRemotes, value);
+            set
+            {
+                if (SetProperty(ref _fetchAllRemotes, value) && IsFetchAllRemoteVisible)
+                    _repo.Settings.FetchAllRemotes = value;
+            }
         }
 
         public Models.Remote SelectedRemote
@@ -37,7 +46,8 @@ namespace SourceGit.ViewModels
         public Fetch(Repository repo, Models.Remote preferredRemote = null)
         {
             _repo = repo;
-            _fetchAllRemotes = preferredRemote == null;
+            IsFetchAllRemoteVisible = repo.Remotes.Count > 1 && preferredRemote == null;
+            _fetchAllRemotes = IsFetchAllRemoteVisible && _repo.Settings.FetchAllRemotes;
 
             if (preferredRemote != null)
             {
@@ -92,6 +102,6 @@ namespace SourceGit.ViewModels
         }
 
         private readonly Repository _repo = null;
-        private bool _fetchAllRemotes;
+        private bool _fetchAllRemotes = false;
     }
 }
