@@ -193,7 +193,7 @@ namespace SourceGit.ViewModels
             }
         }
 
-        public bool CheckoutBranchByDecorator(Models.Decorator decorator)
+        public async Task<bool> CheckoutBranchByDecoratorAsync(Models.Decorator decorator)
         {
             if (decorator == null)
                 return false;
@@ -208,7 +208,7 @@ namespace SourceGit.ViewModels
                 if (b == null)
                     return false;
 
-                _repo.CheckoutBranch(b);
+                await _repo.CheckoutBranchAsync(b);
                 return true;
             }
 
@@ -219,19 +219,19 @@ namespace SourceGit.ViewModels
                     return false;
 
                 var lb = _repo.Branches.Find(x => x.IsLocal && x.Upstream == rb.FullName);
-                if (lb == null || lb.TrackStatus.Ahead.Count > 0)
+                if (lb == null || lb.Ahead.Count > 0)
                 {
                     if (_repo.CanCreatePopup())
                         _repo.ShowPopup(new CreateBranch(_repo, rb));
                 }
-                else if (lb.TrackStatus.Behind.Count > 0)
+                else if (lb.Behind.Count > 0)
                 {
                     if (_repo.CanCreatePopup())
                         _repo.ShowPopup(new CheckoutAndFastForward(_repo, lb, rb));
                 }
                 else if (!lb.IsCurrent)
                 {
-                    _repo.CheckoutBranch(lb);
+                    await _repo.CheckoutBranchAsync(lb);
                 }
 
                 return true;
@@ -240,7 +240,7 @@ namespace SourceGit.ViewModels
             return false;
         }
 
-        public void CheckoutBranchByCommit(Models.Commit commit)
+        public async Task CheckoutBranchByCommitAsync(Models.Commit commit)
         {
             if (commit.IsCurrentHead)
                 return;
@@ -254,7 +254,7 @@ namespace SourceGit.ViewModels
                     if (b == null)
                         continue;
 
-                    _repo.CheckoutBranch(b);
+                    await _repo.CheckoutBranchAsync(b);
                     return;
                 }
 
@@ -265,7 +265,7 @@ namespace SourceGit.ViewModels
                         continue;
 
                     var lb = _repo.Branches.Find(x => x.IsLocal && x.Upstream == rb.FullName);
-                    if (lb is { TrackStatus.Ahead.Count: 0 })
+                    if (lb.Ahead.Count == 0)
                     {
                         if (_repo.CanCreatePopup())
                             _repo.ShowPopup(new CheckoutAndFastForward(_repo, lb, rb));
