@@ -38,7 +38,7 @@ namespace SourceGit.ViewModels
             Strategy = Models.MergeStrategy.ForMultiple[0];
         }
 
-        public override Task<bool> Sure()
+        public override async Task<bool> Sure()
         {
             _repo.SetWatcherEnabled(false);
             _repo.ClearCommitMessage();
@@ -47,18 +47,17 @@ namespace SourceGit.ViewModels
             var log = _repo.CreateLog("Merge Multiple Heads");
             Use(log);
 
-            return Task.Run(() =>
-            {
-                new Commands.Merge(
-                    _repo.FullPath,
-                    ConvertTargetToMergeSources(),
-                    AutoCommit,
-                    Strategy.Arg).Use(log).Exec();
+            await new Commands.Merge(
+                _repo.FullPath,
+                ConvertTargetToMergeSources(),
+                AutoCommit,
+                Strategy.Arg)
+                .Use(log)
+                .ExecAsync();
 
-                log.Complete();
-                CallUIThread(() => _repo.SetWatcherEnabled(true));
-                return true;
-            });
+            log.Complete();
+            _repo.SetWatcherEnabled(true);
+            return true;
         }
 
         private List<string> ConvertTargetToMergeSources()
