@@ -119,6 +119,12 @@ namespace SourceGit.ViewModels
             set => SetProperty(ref _layout, value);
         }
 
+        public bool ShowLocalChangesByDefault
+        {
+            get;
+            set;
+        } = false;
+
         public int MaxHistoryCommits
         {
             get => _maxHistoryCommits;
@@ -152,6 +158,12 @@ namespace SourceGit.ViewModels
             set => SetProperty(ref _useFixedTabWidth, value);
         }
 
+        public bool UseAutoHideScrollBars
+        {
+            get => _useAutoHideScrollBars;
+            set => SetProperty(ref _useAutoHideScrollBars, value);
+        }
+
         public bool Check4UpdatesOnStartup
         {
             get => _check4UpdatesOnStartup;
@@ -255,18 +267,18 @@ namespace SourceGit.ViewModels
             set => SetProperty(ref _useFullTextDiff, value);
         }
 
-        public bool UseBlockNavigationInDiffView
-        {
-            get => _useBlockNavigationInDiffView;
-            set => SetProperty(ref _useBlockNavigationInDiffView, value);
-        }
-
         public int LFSImageActiveIdx
         {
             get => _lfsImageActiveIdx;
             set => SetProperty(ref _lfsImageActiveIdx, value);
         }
 
+        public bool EnableCompactFoldersInChangesTree
+        {
+            get => _enableCompactFoldersInChangesTree;
+            set => SetProperty(ref _enableCompactFoldersInChangesTree, value);
+        }
+
         public Models.ChangeViewMode UnstagedChangeViewMode
         {
             get => _unstagedChangeViewMode;
@@ -695,11 +707,12 @@ namespace SourceGit.ViewModels
         private double _defaultFontSize = 13;
         private double _editorFontSize = 13;
         private int _editorTabWidth = 4;
-        private LayoutInfo _layout = new LayoutInfo();
+        private LayoutInfo _layout = new();
 
         private int _maxHistoryCommits = 20000;
         private int _subjectGuideLength = 50;
         private bool _useFixedTabWidth = true;
+        private bool _useAutoHideScrollBars = true;
         private bool _showAuthorTimeInGraph = false;
         private bool _showChildren = false;
 
@@ -716,8 +729,8 @@ namespace SourceGit.ViewModels
         private bool _enableDiffViewWordWrap = false;
         private bool _showHiddenSymbolsInDiffView = false;
         private bool _useFullTextDiff = false;
-        private bool _useBlockNavigationInDiffView = false;
         private int _lfsImageActiveIdx = 0;
+        private bool _enableCompactFoldersInChangesTree = false;
 
         private Models.ChangeViewMode _unstagedChangeViewMode = Models.ChangeViewMode.List;
         private Models.ChangeViewMode _stagedChangeViewMode = Models.ChangeViewMode.List;
