@@ -12,7 +12,7 @@ namespace SourceGit.ViewModels
         }
 
         [Required(ErrorMessage = "Branch name is required!!!")]
-        [RegularExpression(@"^[\w \-/\.#\+]+$", ErrorMessage = "Bad branch name format!")]
+        [RegularExpression(@"^[\w\-/\.#\+]+$", ErrorMessage = "Bad branch name format!")]
         [CustomValidation(typeof(RenameBranch), nameof(ValidateBranchName))]
         public string Name
         {
@@ -31,10 +31,9 @@ namespace SourceGit.ViewModels
         {
             if (ctx.ObjectInstance is RenameBranch rename)
             {
-                var fixedName = Models.Branch.FixName(name);
                 foreach (var b in rename._repo.Branches)
                 {
-                    if (b.IsLocal && b != rename.Target && b.Name.Equals(fixedName, StringComparison.Ordinal))
+                    if (b.IsLocal && b != rename.Target && b.Name.Equals(name, StringComparison.Ordinal))
                         return new ValidationResult("A branch with same name already exists!!!");
                 }
             }
@@ -44,8 +43,7 @@ namespace SourceGit.ViewModels
 
         public override async Task<bool> Sure()
         {
-            var fixedName = Models.Branch.FixName(_name);
-            if (fixedName.Equals(Target.Name, StringComparison.Ordinal))
+            if (Target.Name.Equals(_name, StringComparison.Ordinal))
                 return true;
 
             _repo.SetWatcherEnabled(false);
@@ -59,7 +57,7 @@ namespace SourceGit.ViewModels
 
             var succ = await new Commands.Branch(_repo.FullPath, Target.Name)
                 .Use(log)
-                .RenameAsync(fixedName);
+                .RenameAsync(_name);
 
             if (succ)
             {
@@ -68,7 +66,7 @@ namespace SourceGit.ViewModels
                     if (filter.Type == Models.FilterType.LocalBranch &&
                         filter.Pattern.Equals(oldName, StringComparison.Ordinal))
                     {
-                        filter.Pattern = $"refs/heads/{fixedName}";
+                        filter.Pattern = $"refs/heads/{_name}";
                         break;
                     }
                 }
