@@ -30,7 +30,7 @@ namespace SourceGit.ViewModels
             To = to;
         }
 
-        public override Task<bool> Sure()
+        public override async Task<bool> Sure()
         {
             _repo.SetWatcherEnabled(false);
             ProgressDescription = $"Reset {Target.Name} to {_revision} ...";
@@ -38,13 +38,14 @@ namespace SourceGit.ViewModels
             var log = _repo.CreateLog($"Reset '{Target.Name}' to '{_revision}'");
             Use(log);
 
-            return Task.Run(() =>
-            {
-                var succ = Commands.Branch.Create(_repo.FullPath, Target.Name, _revision, true, log);
-                log.Complete();
-                CallUIThread(() => _repo.SetWatcherEnabled(true));
-                return succ;
-            });
+            var succ = await new Commands.Branch(_repo.FullPath, Target.Name)
+                .Use(log)
+                .CreateAsync(_revision, true);
+
+            log.Complete();
+            _repo.MarkBranchesDirtyManually();
+            _repo.SetWatcherEnabled(true);
+            return succ;
         }
 
         private readonly Repository _repo = null;
