@@ -1,6 +1,7 @@
 ﻿using System;
 using System.Collections.Generic;
 using System.IO;
+using System.Threading;
 using System.Threading.Tasks;
 
 using Avalonia.Threading;
@@ -70,6 +71,12 @@ namespace SourceGit.ViewModels
             set => _repo.Settings.EnableSignOffForCommit = value;
         }
 
+        public bool NoVerifyOnCommit
+        {
+            get => _repo.Settings.NoVerifyOnCommit;
+            set => _repo.Settings.NoVerifyOnCommit = value;
+        }
+
         public bool UseAmend
         {
             get => _useAmend;
@@ -88,9 +95,7 @@ namespace SourceGit.ViewModels
                             return;
                         }
 
-                        CommitMessage = new Commands.QueryCommitFullMessage(_repo.FullPath, currentBranch.Head)
-                            .GetResultAsync()
-                            .Result;
+                        CommitMessage = new Commands.QueryCommitFullMessage(_repo.FullPath, currentBranch.Head).GetResult();
                     }
                     else
                     {
@@ -248,15 +253,17 @@ namespace SourceGit.ViewModels
             _commitMessage = string.Empty;
         }
 
-        public void SetData(List<Models.Change> changes)
+        public void SetData(List<Models.Change> changes, CancellationToken cancellationToken)
         {
             if (!IsChanged(_cached, changes))
             {
                 // Just force refresh selected changes.
                 Dispatcher.UIThread.Invoke(() =>
                 {
-                    HasUnsolvedConflicts = _cached.Find(x => x.IsConflicted) != null;
+                    if (cancellationToken.IsCancellationRequested)
+                        return;
 
+                    HasUnsolvedConflicts = _cached.Find(x => x.IsConflicted) != null;
                     UpdateDetail();
                     UpdateInProgressState();
                 });
@@ -310,6 +317,9 @@ namespace SourceGit.ViewModels
 
             Dispatcher.UIThread.Invoke(() =>
             {
+                if (cancellationToken.IsCancellationRequested)
+                    return;
+
                 _isLoadingData = true;
                 HasUnsolvedConflicts = hasConflict;
                 VisibleUnstaged = visibleUnstaged;
@@ -332,13 +342,13 @@ namespace SourceGit.ViewModels
                 Native.OS.OpenWithDefaultEditor(absPath);
         }
 
-        public void StashAll(bool autoStart)
+        public async Task StashAllAsync(bool autoStart)
         {
             if (!_repo.CanCreatePopup())
                 return;
 
             if (autoStart)
-                _repo.ShowAndStartPopup(new StashChanges(_repo, _cached, false));
+                await _repo.ShowAndStartPopupAsync(new StashChanges(_repo, _cached, false));
             else
                 _repo.ShowPopup(new StashChanges(_repo, _cached, false));
         }
@@ -419,7 +429,7 @@ namespace SourceGit.ViewModels
 
         public async Task SaveChangesToPatchAsync(List<Models.Change> changes, bool isUnstaged, string saveTo)
         {
-            var succ = await Commands.SaveChangesAsPatch.ProcessLocalChangesAsync(_repo.FullPath, _selectedUnstaged, isUnstaged, saveTo);
+            var succ = await Commands.SaveChangesAsPatch.ProcessLocalChangesAsync(_repo.FullPath, changes, isUnstaged, saveTo);
             if (succ)
                 App.SendNotification(_repo.FullPath, App.Text("SaveAsPatchSuccess"));
         }
@@ -608,19 +618,100 @@ namespace SourceGit.ViewModels
             CommitMessage = tmpl.Apply(_repo.CurrentBranch, _staged);
         }
 
-        public void Commit()
+        public async Task ClearCommitMessageHistoryAsync()
         {
-            DoCommit(false, false);
+            var sure = await App.AskConfirmAsync(App.Text("WorkingCopy.ClearCommitHistories.Confirm"));
+            if (sure)
+                _repo.Settings.CommitMessages.Clear();
         }
 
-        public void CommitWithAutoStage()
+        public async Task CommitAsync(bool autoStage, bool autoPush)
         {
-            DoCommit(true, false);
-        }
+            if (string.IsNullOrWhiteSpace(_commitMessage))
+                return;
 
-        public void CommitWithPush()
-        {
-            DoCommit(false, true);
+            if (!_repo.CanCreatePopup())
+            {
+                App.RaiseException(_repo.FullPath, "Repository has an unfinished job! Please wait!");
+                return;
+            }
+
+            if (autoStage && HasUnsolvedConflicts)
+            {
+                App.RaiseException(_repo.FullPath, "Repository has unsolved conflict(s). Auto-stage and commit is disabled!");
+                return;
+            }
+
+            if (_repo.CurrentBranch is { IsDetachedHead: true })
+            {
+                var msg = App.Text("WorkingCopy.ConfirmCommitWithDetachedHead");
+                var sure = await App.AskConfirmAsync(msg);
+                if (!sure)
+                    return;
+            }
+
+            if (!string.IsNullOrEmpty(_filter) && _staged.Count > _visibleStaged.Count)
+            {
+                var msg = App.Text("WorkingCopy.ConfirmCommitWithFilter", _staged.Count, _visibleStaged.Count, _staged.Count - _visibleStaged.Count);
+                var sure = await App.AskConfirmAsync(msg);
+                if (!sure)
+                    return;
+            }
+
+            if (!_useAmend)
+            {
+                if ((!autoStage && _staged.Count == 0) || (autoStage && _cached.Count == 0))
+                {
+                    var rs = await App.AskConfirmEmptyCommitAsync(_cached.Count > 0);
+                    if (rs == Models.ConfirmEmptyCommitResult.Cancel)
+                        return;
+
+                    if (rs == Models.ConfirmEmptyCommitResult.StageAllAndCommit)
+                        autoStage = true;
+                }
+            }
+
+            IsCommitting = true;
+            _repo.Settings.PushCommitMessage(_commitMessage);
+            _repo.SetWatcherEnabled(false);
+
+            var log = _repo.CreateLog("Commit");
+            var succ = true;
+            if (autoStage && _unstaged.Count > 0)
+                succ = await new Commands.Add(_repo.FullPath, _repo.IncludeUntracked)
+                    .Use(log)
+                    .ExecAsync()
+                    .ConfigureAwait(false);
+
+            if (succ)
+                succ = await new Commands.Commit(_repo.FullPath, _commitMessage, EnableSignOff, NoVerifyOnCommit, _useAmend, _resetAuthor)
+                    .Use(log)
+                    .RunAsync()
+                    .ConfigureAwait(false);
+
+            log.Complete();
+
+            if (succ)
+            {
+                CommitMessage = string.Empty;
+                UseAmend = false;
+                if (autoPush && _repo.Remotes.Count > 0)
+                {
+                    Models.Branch pushBranch = null;
+                    if (_repo.CurrentBranch == null)
+                    {
+                        var currentBranchName = await new Commands.QueryCurrentBranch(_repo.FullPath).GetResultAsync();
+                        pushBranch = new Models.Branch() { Name = currentBranchName };
+                    }
+
+                    if (_repo.CanCreatePopup())
+                        await _repo.ShowAndStartPopupAsync(new Push(_repo, pushBranch));
+                }
+            }
+
+            _repo.MarkBranchesDirtyManually();
+            _repo.SetWatcherEnabled(true);
+            IsCommitting = false;
         }
 
         private List<Models.Change> GetVisibleChanges(List<Models.Change> changes)
@@ -670,13 +761,8 @@ namespace SourceGit.ViewModels
         {
             if (_useAmend)
             {
-                var head = new Commands.QuerySingleCommit(_repo.FullPath, "HEAD")
-                    .GetResultAsync()
-                    .Result;
-
-                return new Commands.QueryStagedChangesWithAmend(_repo.FullPath, head.Parents.Count == 0 ? Models.Commit.EmptyTreeSHA1 : $"{head.SHA}^")
-                    .GetResultAsync()
-                    .Result;
+                var head = new Commands.QuerySingleCommit(_repo.FullPath, "HEAD").GetResult();
+                return new Commands.QueryStagedChangesWithAmend(_repo.FullPath, head.Parents.Count == 0 ? Models.Commit.EmptyTreeSHA1 : $"{head.SHA}^").GetResult();
             }
 
             var rs = new List<Models.Change>();
@@ -722,7 +808,7 @@ namespace SourceGit.ViewModels
                     if (File.Exists(rebaseMsgFile))
                         CommitMessage = File.ReadAllText(rebaseMsgFile);
                     else if (rebasing.StoppedAt != null)
-                        CommitMessage = new Commands.QueryCommitFullMessage(_repo.FullPath, rebasing.StoppedAt.SHA).GetResultAsync().Result;
+                        CommitMessage = new Commands.QueryCommitFullMessage(_repo.FullPath, rebasing.StoppedAt.SHA).GetResult();
                 }
             }
             else if (File.Exists(Path.Combine(_repo.GitDir, "REVERT_HEAD")))
@@ -752,92 +838,6 @@ namespace SourceGit.ViewModels
                 DetailContext = new DiffContext(_repo.FullPath, new Models.DiffOption(change, isUnstaged), _detailContext as DiffContext);
         }
 
-        private void DoCommit(bool autoStage, bool autoPush, CommitCheckPassed checkPassed = CommitCheckPassed.None)
-        {
-            if (string.IsNullOrWhiteSpace(_commitMessage))
-                return;
-
-            if (!_repo.CanCreatePopup())
-            {
-                App.RaiseException(_repo.FullPath, "Repository has an unfinished job! Please wait!");
-                return;
-            }
-
-            if (autoStage && HasUnsolvedConflicts)
-            {
-                App.RaiseException(_repo.FullPath, "Repository has unsolved conflict(s). Auto-stage and commit is disabled!");
-                return;
-            }
-
-            if (_repo.CurrentBranch is { IsDetachedHead: true } && checkPassed < CommitCheckPassed.DetachedHead)
-            {
-                var msg = App.Text("WorkingCopy.ConfirmCommitWithDetachedHead");
-                _ = App.AskConfirmAsync(msg, () => DoCommit(autoStage, autoPush, CommitCheckPassed.DetachedHead));
-                return;
-            }
-
-            if (!string.IsNullOrEmpty(_filter) && _staged.Count > _visibleStaged.Count && checkPassed < CommitCheckPassed.Filter)
-            {
-                var msg = App.Text("WorkingCopy.ConfirmCommitWithFilter", _staged.Count, _visibleStaged.Count, _staged.Count - _visibleStaged.Count);
-                _ = App.AskConfirmAsync(msg, () => DoCommit(autoStage, autoPush, CommitCheckPassed.Filter));
-                return;
-            }
-
-            if (checkPassed < CommitCheckPassed.FileCount && !_useAmend)
-            {
-                if ((!autoStage && _staged.Count == 0) || (autoStage && _cached.Count == 0))
-                {
-                    _ = App.ShowDialog(new ConfirmEmptyCommit(_cached.Count > 0, stageAll => DoCommit(stageAll, autoPush, CommitCheckPassed.FileCount)));
-                    return;
-                }
-            }
-
-            IsCommitting = true;
-            _repo.Settings.PushCommitMessage(_commitMessage);
-            _repo.SetWatcherEnabled(false);
-
-            var signOff = _repo.Settings.EnableSignOffForCommit;
-            var log = _repo.CreateLog("Commit");
-            Task.Run(async () =>
-            {
-                var succ = true;
-                if (autoStage && _unstaged.Count > 0)
-                    succ = await new Commands.Add(_repo.FullPath, _repo.IncludeUntracked).Use(log).ExecAsync().ConfigureAwait(false);
-
-                if (succ)
-                    succ = await new Commands.Commit(_repo.FullPath, _commitMessage, signOff, _useAmend, _resetAuthor).Use(log).RunAsync().ConfigureAwait(false);
-
-                log.Complete();
-
-                Dispatcher.UIThread.Post(async () =>
-                {
-                    if (succ)
-                    {
-                        CommitMessage = string.Empty;
-                        UseAmend = false;
-
-                        if (autoPush && _repo.Remotes.Count > 0)
-                        {
-                            if (_repo.CurrentBranch == null)
-                            {
-                                var currentBranchName = await new Commands.QueryCurrentBranch(_repo.FullPath).GetResultAsync();
-                                var tmp = new Models.Branch() { Name = currentBranchName };
-                                _repo.ShowAndStartPopup(new Push(_repo, tmp));
-                            }
-                            else
-                            {
-                                _repo.ShowAndStartPopup(new Push(_repo, null));
-                            }
-                        }
-                    }
-
-                    _repo.MarkBranchesDirtyManually();
-                    _repo.SetWatcherEnabled(true);
-                    IsCommitting = false;
-                });
-            });
-        }
-
         private bool IsChanged(List<Models.Change> old, List<Models.Change> cur)
         {
             if (old.Count != cur.Count)
@@ -854,14 +854,6 @@ namespace SourceGit.ViewModels
             return false;
         }
 
-        private enum CommitCheckPassed
-        {
-            None = 0,
-            DetachedHead,
-            Filter,
-            FileCount,
-        }
-
         private Repository _repo = null;
         private bool _isLoadingData = false;
         private bool _isStaging = false;
