@@ -188,9 +188,9 @@ namespace SourceGit.Views
             SetCurrentValue(IsScrollToTopVisibleProperty, startY >= rowHeight);
 
             var clipWidth = dataGrid.Columns[0].ActualWidth - 4;
-            if (_lastGraphStartY != startY ||
-                _lastGraphClipWidth != clipWidth ||
-                _lastGraphRowHeight != rowHeight)
+            if (Math.Abs(_lastGraphStartY - startY) > 0.01 ||
+                Math.Abs(_lastGraphClipWidth - clipWidth) > 0.01 ||
+                Math.Abs(_lastGraphRowHeight - rowHeight) > 0.01)
             {
                 _lastGraphStartY = startY;
                 _lastGraphClipWidth = clipWidth;
@@ -292,13 +292,11 @@ namespace SourceGit.Views
                         repo.ShowPopup(new ViewModels.CreateTag(repo, commit));
                         e.Handled = true;
                     }
-
-                    return;
                 }
             }
         }
 
-        private void OnCommitListDoubleTapped(object sender, TappedEventArgs e)
+        private async void OnCommitListDoubleTapped(object sender, TappedEventArgs e)
         {
             e.Handled = true;
 
@@ -310,12 +308,13 @@ namespace SourceGit.Views
                 if (e.Source is CommitRefsPresenter crp)
                 {
                     var decorator = crp.DecoratorAt(e.GetPosition(crp));
-                    if (histories.CheckoutBranchByDecorator(decorator))
+                    var succ = await histories.CheckoutBranchByDecoratorAsync(decorator);
+                    if (succ)
                         return;
                 }
 
                 if (e.Source is Control { DataContext: Models.Commit c })
-                    histories.CheckoutBranchByCommit(c);
+                    await histories.CheckoutBranchByCommitAsync(c);
             }
         }
 
@@ -712,7 +711,7 @@ namespace SourceGit.Views
 
             if (!isHead)
             {
-                if (current.TrackStatus.Ahead.Contains(commit.SHA))
+                if (current.Ahead.Contains(commit.SHA))
                 {
                     var upstream = repo.Branches.Find(x => x.FullName.Equals(current.Upstream, StringComparison.Ordinal));
                     var pushRevision = new MenuItem();
@@ -774,7 +773,7 @@ namespace SourceGit.Views
                     {
                         var folder = selected[0];
                         var folderPath = folder is { Path: { IsAbsoluteUri: true } path } ? path.LocalPath : folder.Path.ToString();
-                        await repo.SaveCommitAsPatchAsync(commit, folderPath, 0);
+                        await repo.SaveCommitAsPatchAsync(commit, folderPath);
                     }
                 }
                 catch (Exception exception)
@@ -811,9 +810,9 @@ namespace SourceGit.Views
                     var item = new MenuItem();
                     item.Icon = App.CreateMenuIcon("Icons.Action");
                     item.Header = label;
-                    item.Click += (_, e) =>
+                    item.Click += async (_, e) =>
                     {
-                        repo.ExecCustomAction(dup, commit);
+                        await repo.ExecCustomActionAsync(dup, commit);
                         e.Handled = true;
                     };
 
@@ -912,15 +911,15 @@ namespace SourceGit.Views
                 var fastForward = new MenuItem();
                 fastForward.Header = App.Text("BranchCM.FastForward", upstream);
                 fastForward.Icon = App.CreateMenuIcon("Icons.FastForward");
-                fastForward.IsEnabled = current.TrackStatus.Ahead.Count == 0 && current.TrackStatus.Behind.Count > 0;
-                fastForward.Click += (_, e) =>
+                fastForward.IsEnabled = current.Ahead.Count == 0 && current.Behind.Count > 0;
+                fastForward.Click += async (_, e) =>
                 {
                     var b = repo.Branches.Find(x => x.FriendlyName == upstream);
                     if (b == null)
                         return;
 
                     if (repo.CanCreatePopup())
-                        repo.ShowAndStartPopup(new ViewModels.Merge(repo, b, current.Name, true));
+                        await repo.ShowAndStartPopupAsync(new ViewModels.Merge(repo, b, current.Name, true));
 
                     e.Handled = true;
                 };
@@ -1011,9 +1010,9 @@ namespace SourceGit.Views
                 var checkout = new MenuItem();
                 checkout.Header = App.Text("BranchCM.Checkout", branch.Name);
                 checkout.Icon = App.CreateMenuIcon("Icons.Check");
-                checkout.Click += (_, e) =>
+                checkout.Click += async (_, e) =>
                 {
-                    repo.CheckoutBranch(branch);
+                    await repo.CheckoutBranchAsync(branch);
                     e.Handled = true;
                 };
                 submenu.Items.Add(checkout);
@@ -1103,9 +1102,9 @@ namespace SourceGit.Views
             var checkout = new MenuItem();
             checkout.Header = App.Text("BranchCM.Checkout", name);
             checkout.Icon = App.CreateMenuIcon("Icons.Check");
-            checkout.Click += (_, e) =>
+            checkout.Click += async (_, e) =>
             {
-                repo.CheckoutBranch(branch);
+                await repo.CheckoutBranchAsync(branch);
                 e.Handled = true;
             };
             submenu.Items.Add(checkout);
@@ -1200,7 +1199,7 @@ namespace SourceGit.Views
             submenu.Items.Add(new MenuItem() { Header = "-" });
 
             var copy = new MenuItem();
-            copy.Header = App.Text("TagCM.Copy");
+            copy.Header = App.Text("TagCM.CopyName");
             copy.Icon = App.CreateMenuIcon("Icons.Copy");
             copy.Click += async (_, e) =>
             {
