@@ -1,7 +1,6 @@
 ﻿using System;
 
 using Avalonia;
-using Avalonia.Collections;
 using Avalonia.Controls;
 using Avalonia.Input;
 using Avalonia.Interactivity;
@@ -20,20 +19,6 @@ namespace SourceGit.Views
             set => SetValue(IsScrollerVisibleProperty, value);
         }
 
-        public static readonly StyledProperty<string> SearchFilterProperty =
-            AvaloniaProperty.Register<LauncherTabBar, string>(nameof(SearchFilter));
-
-        public string SearchFilter
-        {
-            get => GetValue(SearchFilterProperty);
-            set => SetValue(SearchFilterProperty, value);
-        }
-
-        public AvaloniaList<ViewModels.LauncherPage> SelectablePages
-        {
-            get;
-        } = [];
-
         public LauncherTabBar()
         {
             InitializeComponent();
@@ -141,14 +126,6 @@ namespace SourceGit.Views
             context.DrawGeometry(fill, stroke, geo);
         }
 
-        protected override void OnPropertyChanged(AvaloniaPropertyChangedEventArgs change)
-        {
-            base.OnPropertyChanged(change);
-
-            if (change.Property == SearchFilterProperty)
-                UpdateSelectablePages();
-        }
-
         private void ScrollTabs(object _, PointerWheelEventArgs e)
         {
             if (!e.KeyModifiers.HasFlag(KeyModifiers.Shift))
@@ -261,28 +238,28 @@ namespace SourceGit.Views
                 var close = new MenuItem();
                 close.Header = App.Text("PageTabBar.Tab.Close");
                 close.Tag = OperatingSystem.IsMacOS() ? "⌘+W" : "Ctrl+W";
-                close.Click += (_, e) =>
+                close.Click += (_, ev) =>
                 {
                     vm.CloseTab(page);
-                    e.Handled = true;
+                    ev.Handled = true;
                 };
                 menu.Items.Add(close);
 
                 var closeOthers = new MenuItem();
                 closeOthers.Header = App.Text("PageTabBar.Tab.CloseOther");
-                closeOthers.Click += (_, e) =>
+                closeOthers.Click += (_, ev) =>
                 {
                     vm.CloseOtherTabs();
-                    e.Handled = true;
+                    ev.Handled = true;
                 };
                 menu.Items.Add(closeOthers);
 
                 var closeRight = new MenuItem();
                 closeRight.Header = App.Text("PageTabBar.Tab.CloseRight");
-                closeRight.Click += (_, e) =>
+                closeRight.Click += (_, ev) =>
                 {
                     vm.CloseRightTabs();
-                    e.Handled = true;
+                    ev.Handled = true;
                 };
                 menu.Items.Add(closeRight);
 
@@ -302,10 +279,10 @@ namespace SourceGit.Views
                         var dupIdx = i;
                         var setter = new MenuItem();
                         setter.Header = icon;
-                        setter.Click += (_, e) =>
+                        setter.Click += (_, ev) =>
                         {
                             page.Node.Bookmark = dupIdx;
-                            e.Handled = true;
+                            ev.Handled = true;
                         };
                         bookmark.Items.Add(setter);
                     }
@@ -315,10 +292,10 @@ namespace SourceGit.Views
                     var copyPath = new MenuItem();
                     copyPath.Header = App.Text("PageTabBar.Tab.CopyPath");
                     copyPath.Icon = App.CreateMenuIcon("Icons.Copy");
-                    copyPath.Click += async (_, e) =>
+                    copyPath.Click += async (_, ev) =>
                     {
                         await page.CopyPathAsync();
-                        e.Handled = true;
+                        ev.Handled = true;
                     };
                     menu.Items.Add(new MenuItem() { Header = "-" });
                     menu.Items.Add(copyPath);
@@ -337,99 +314,8 @@ namespace SourceGit.Views
             e.Handled = true;
         }
 
-        private void OnTabsDropdownOpened(object sender, EventArgs e)
-        {
-            UpdateSelectablePages();
-        }
-
-        private void OnTabsDropdownClosed(object sender, EventArgs e)
-        {
-            SelectablePages.Clear();
-            SearchFilter = string.Empty;
-        }
-
-        private void OnTabsDropdownKeyDown(object sender, KeyEventArgs e)
-        {
-            if (e.Key == Key.Escape)
-            {
-                PageSelector.Flyout?.Hide();
-                e.Handled = true;
-            }
-            else if (e.Key == Key.Enter)
-            {
-                if (TabsDropdownList.SelectedItem is ViewModels.LauncherPage page &&
-                    DataContext is ViewModels.Launcher vm)
-                {
-                    vm.ActivePage = page;
-                    PageSelector.Flyout?.Hide();
-                    e.Handled = true;
-                }
-            }
-        }
-
-        private void OnTabsDropdownSearchBoxKeyDown(object sender, KeyEventArgs e)
-        {
-            if (e.Key == Key.Down && TabsDropdownList.ItemCount > 0)
-            {
-                TabsDropdownList.Focus(NavigationMethod.Directional);
-
-                if (TabsDropdownList.SelectedIndex < 0)
-                    TabsDropdownList.SelectedIndex = 0;
-                else if (TabsDropdownList.SelectedIndex < TabsDropdownList.ItemCount)
-                    TabsDropdownList.SelectedIndex++;
-
-                e.Handled = true;
-            }
-        }
-
-        private void OnTabsDropdownLostFocus(object sender, RoutedEventArgs e)
-        {
-            if (sender is Control { IsFocused: false, IsKeyboardFocusWithin: false })
-                PageSelector.Flyout?.Hide();
-        }
-
-        private void OnClearSearchFilter(object sender, RoutedEventArgs e)
-        {
-            SearchFilter = string.Empty;
-        }
-
-        private void OnTabsDropdownItemTapped(object sender, TappedEventArgs e)
-        {
-            if (sender is Control { DataContext: ViewModels.LauncherPage page } &&
-                DataContext is ViewModels.Launcher vm)
-            {
-                vm.ActivePage = page;
-                PageSelector.Flyout?.Hide();
-                e.Handled = true;
-            }
-        }
-
-        private void UpdateSelectablePages()
-        {
-            if (DataContext is not ViewModels.Launcher vm)
-                return;
-
-            SelectablePages.Clear();
-
-            var pages = vm.Pages;
-            var filter = SearchFilter?.Trim() ?? "";
-            if (string.IsNullOrEmpty(filter))
-            {
-                SelectablePages.AddRange(pages);
-                return;
-            }
-
-            foreach (var page in pages)
-            {
-                var node = page.Node;
-                if (node.Name.Contains(filter, StringComparison.OrdinalIgnoreCase) ||
-                    (node.IsRepository && node.Id.Contains(filter, StringComparison.OrdinalIgnoreCase)))
-                    SelectablePages.Add(page);
-            }
-        }
-
         private bool _pressedTab = false;
-        private Point _pressedTabPosition = new Point();
+        private Point _pressedTabPosition = new();
         private bool _startDragTab = false;
     }
 }
