@@ -113,6 +113,18 @@ namespace SourceGit.Views
                     vm.OpenWithDefaultEditor(vm.SelectedUnstaged[0]);
                     e.Handled = true;
                 }
+                else if (e.Key is Key.C &&
+                         e.KeyModifiers.HasFlag(OperatingSystem.IsMacOS() ? KeyModifiers.Meta : KeyModifiers.Control) &&
+                         vm.SelectedUnstaged is { Count: 1 })
+                {
+                    var change = vm.SelectedUnstaged[0];
+                    if (e.KeyModifiers.HasFlag(KeyModifiers.Shift))
+                        await App.CopyTextAsync(Native.OS.GetAbsPath(vm.Repository.FullPath, change.Path));
+                    else
+                        await App.CopyTextAsync(change.Path);
+
+                    e.Handled = true;
+                }
             }
         }
 
@@ -134,6 +146,18 @@ namespace SourceGit.Views
                     vm.OpenWithDefaultEditor(vm.SelectedStaged[0]);
                     e.Handled = true;
                 }
+                else if (e.Key is Key.C &&
+                         e.KeyModifiers.HasFlag(OperatingSystem.IsMacOS() ? KeyModifiers.Meta : KeyModifiers.Control) &&
+                         vm.SelectedStaged is { Count: 1 })
+                {
+                    var change = vm.SelectedStaged[0];
+                    if (e.KeyModifiers.HasFlag(KeyModifiers.Shift))
+                        await App.CopyTextAsync(Native.OS.GetAbsPath(vm.Repository.FullPath, change.Path));
+                    else
+                        await App.CopyTextAsync(change.Path);
+
+                    e.Handled = true;
+                }
             }
         }
 
@@ -193,6 +217,30 @@ namespace SourceGit.Views
             e.Handled = true;
         }
 
+        private async void OnCommit(object _, RoutedEventArgs e)
+        {
+            if (DataContext is ViewModels.WorkingCopy vm)
+                await vm.CommitAsync(false, false);
+
+            e.Handled = true;
+        }
+
+        private async void OnCommitWithAutoStage(object _, RoutedEventArgs e)
+        {
+            if (DataContext is ViewModels.WorkingCopy vm)
+                await vm.CommitAsync(true, false);
+
+            e.Handled = true;
+        }
+
+        private async void OnCommitWithPush(object _, RoutedEventArgs e)
+        {
+            if (DataContext is ViewModels.WorkingCopy vm)
+                await vm.CommitAsync(false, true);
+
+            e.Handled = true;
+        }
+
         private ContextMenu CreateContextMenuForUnstagedChanges(ViewModels.WorkingCopy vm, string selectedSingleFolder)
         {
             var repo = vm.Repository;
@@ -391,7 +439,7 @@ namespace SourceGit.Views
                         }
                         else
                         {
-                            var isRooted = change.Path.IndexOf('/') <= 0;
+                            var isRooted = change.Path!.IndexOf('/') <= 0;
                             var singleFile = new MenuItem();
                             singleFile.Header = App.Text("WorkingCopy.AddToGitIgnore.SingleFile");
                             singleFile.Click += (_, e) =>
@@ -457,7 +505,7 @@ namespace SourceGit.Views
                         lfs.Header = App.Text("GitLFS");
                         lfs.Icon = App.CreateMenuIcon("Icons.LFS");
 
-                        var isLFSFiltered = new Commands.IsLFSFiltered(repo.FullPath, change.Path).GetResultAsync().Result;
+                        var isLFSFiltered = new Commands.IsLFSFiltered(repo.FullPath, change.Path).GetResult();
                         if (!isLFSFiltered)
                         {
                             var filename = Path.GetFileName(change.Path);
@@ -572,7 +620,7 @@ namespace SourceGit.Views
                     history.Icon = App.CreateMenuIcon("Icons.Histories");
                     history.Click += (_, e) =>
                     {
-                        App.ShowWindow(new ViewModels.FileHistories(repo, change.Path));
+                        App.ShowWindow(new ViewModels.FileHistories(repo.FullPath, change.Path));
                         e.Handled = true;
                     };
 
@@ -1038,7 +1086,7 @@ namespace SourceGit.Views
                     history.Icon = App.CreateMenuIcon("Icons.Histories");
                     history.Click += (_, e) =>
                     {
-                        App.ShowWindow(new ViewModels.FileHistories(repo, change.Path));
+                        App.ShowWindow(new ViewModels.FileHistories(repo.FullPath, change.Path));
                         e.Handled = true;
                     };
 
@@ -1126,7 +1174,7 @@ namespace SourceGit.Views
                 patch.Icon = App.CreateMenuIcon("Icons.Diff");
                 patch.Click += async (_, e) =>
                 {
-                    var storageProvider = TopLevel.GetTopLevel(this).StorageProvider;
+                    var storageProvider = TopLevel.GetTopLevel(this)?.StorageProvider;
                     if (storageProvider == null)
                         return;
 
